# AI Effects

AI-powered visual effects for background removal, object manipulation,
enhancement, and restoration. All require optional dependencies:
`pip install "pymotion-studio[ai]"`.

## RemoveBackground

::: pymotion.effects.ai.RemoveBackground

## ReplaceBackground

::: pymotion.effects.ai.ReplaceBackground

## ObjectSegmentation

::: pymotion.effects.ai.ObjectSegmentation

## RemoveObject

::: pymotion.effects.ai.RemoveObject

## ExtendFrame

::: pymotion.effects.ai.ExtendFrame

## Upscale

::: pymotion.effects.ai.Upscale

## Denoise

::: pymotion.effects.ai.Denoise

## Deblur

::: pymotion.effects.ai.Deblur

## FrameInterpolation

::: pymotion.effects.ai.FrameInterpolation

## ColorizeClip

::: pymotion.effects.ai.ColorizeClip
